package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````&",```````!``````````)BA````
M`````````$``.``(`$``&0`8``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````.R3````````[),`````````
M``$```````$````&`````)L`````````FP$```````";`0``````@`4`````
M``"H%0```````````0```````@````8````0FP```````!";`0``````$)L!
M``````!0`@```````%`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0`````FP````````";`0```````)L!````````!0``````
M```%`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`2/S-+=Q!0%/Y+6/3FZALOX7`GSH1````3P````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A/````4````%0```!9````6@``
M`&$```!B````8P```&4```!F`````````&@```!I````:@```&P`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`)`<````````````````````````
M`P`5``"@`0`````````````````5`P``$@`````````````````````````N
M`P``$@````````````````````````"U`@``$@``````````````````````
M``#B`@``$@`````````````````````````V`P``$@``````````````````
M``````")`@``$@`````````````````````````1````(```````````````
M``````````##`@``$@````````````````````````"``@``$@``````````
M``````````````#I`@``(@````````````````````````"N`@``$@``````
M``````````````````"7`@``$@````````````````````````"T````$@``
M``````````````````````!$`P``$0````````````````````````"#`0``
M$@````````````````````````#X`@``$@````````````````````````"$
M````$@`````````````````````````,`0``$@``````````````````````
M``!B`@``$@````````````````````````!4`@``$@``````````````````
M``````"J`0``$@`````````````````````````!`0``$0``````````````
M```````````_`@``$@````````````````````````!G`0``$@``````````
M``````````````#C````$0`````````````````````````U`0``$@``````
M``````````````````!B`P``$@`````````````````````````<`P``$@``
M``````````````````````"G`@``$@````````````````````````#"````
M$@````````````````````````"Q`0``$@`````````````````````````B
M`@``$@````````````````````````">`0``$@``````````````````````
M``#P`0``$@````````````````````````"?`@``$@``````````````````
M``````#;`@``$@````````````````````````".`@``$@``````````````
M``````````!1`P``$@`````````````````````````$`@``$@``````````
M``````````````!#`0``$@`````````````````````````M````(```````
M``````````````````">`P``$0````````````````````````!+`P``$@``
M``````````````````````#4`@``$@````````````````````````"\`0``
M$0````````````````````````!D````$@````````````````````````!P
M`P``$@````````````````````````!O`@``$@``````````````````````
M```K!```$@`````````````````````````Y`@``$@``````````````````
M``````"3````$@````````````````````````"?````$@``````````````
M``````````!<`0``$@`````````````````````````*`P``$@``````````
M```````````````B`0``$@`````````````````````````1`0``$@``````
M``````````````````!6````$@````````````````````````!V`@``$@``
M```````````````````````6`0``$@````````````````````````"3`0``
M$@````````````````````````#P````$@````````````````````````!-
M`@``$@````````````````````````!U`0``$@``````````````````````
M``!S````$@`````````````````````````J`@``$@``````````````````
M``````"\`@``$@````````````````````````!^`P``$0``````````````
M``````````"``P``$0`````````````````````````*`@``$@``````````
M``````````````#4````$@````````````````````````!3`0``$@``````
M``````````````````#-`@``$@`````````````````````````\````(```
M```````````````````````1`@``$@````````````````````````!;`@``
M$@````````````````````````!J`P``$@````````````````````````#@
M`P``$``6`*BP`0`````````````````T!```$@`-`'!2````````@```````
M```"!```$@`.`(13``````````````````!9!```$@`-`+A$````````=`D`
M```````I`P``$@`-`-`@````````2`(````````(!```$@`-`+@]````````
M!`````````#1`P``$``6`("@`0````````````````#'!```$@`-`,`]````
M````*`(```````#!!```$@`+`)`<``````````````````#T!```$@`-`#!.
M````````0`0```````#%`P``$``6`("@`0````````````````!`!```$@`-
M`.@_````````*`````````!S!```$0`/`)A3````````!`````````#S`P``
M$``6`*BP`0````````````````#K`P``$``6`*BP`0````````````````"_
M!```$@`-`$@\````````.`````````#4!```$@`-`+!#````````!`$`````
M``#F!```$@`-``!#````````B`````````!F!```$``5``"@`0``````````
M``````!-!```$@`-`!!`````````*`$```````"^`P``$``5`("@`0``````
M``````````"H!```$0`5`'B@`0``````"`````````#X`P``$@`-`(!3````
M````!`````````"8!```$@`-``!3````````@`````````!L!```$@`-`!@C
M``````````````````!H!```(``5``"@`0`````````````````9!```$@`-
M`(A#````````*`````````#?`P``$``6`*BP`0````````````````""!```
M$@`-`-@\````````W`````````"R!```$@`-`#A!````````Q`$`````````
M;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``
M<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A
M=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`')M9&ER`%]?<W1R;F-P>5]C
M:&L`<W1R8VAR`&=E='!I9`!U;FQI;FL`7U]M96UC<'E?8VAK`'-T<F-M<`!R
M96%D9&ER-C0`<F5A9&QI;FL`97AI=`!C;&]S961I<@!O<&5N9&ER`')E86QL
M;V,`;65M<V5T`&=E='5I9`!S=')T;VL`;65M8VAR`%]?>'-T870V-`!S=')S
M='(`86-C97-S`'-T<F1U<`!S=')L96X`7U]C>&%?9FEN86QI>F4`7U]R96=I
M<W1E<E]A=&9O<FL`7U]L>'-T870V-`!M96UC<'D`7U]L:6)C7W-T87)T7VUA
M:6X`;65M;6]V90!?7W-P<FEN=&9?8VAK`'-T9&5R<@!A8F]R=`!?7W-T86-K
M7V-H:U]F86EL`'-T<FYC;7``;6MD:7(`7U]F<')I;G1F7V-H:P!?7V5N=FER
M;VX`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?<W1A8VM?8VAK7V=U87)D`&QI
M8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`
M7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?
M8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C
M;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`
M7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X
M<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV
M7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C$W````````
M```"``(``@`"``(``@````(``@`"``(``@````(````"```````"``(``@``
M``(``````````@`"``(```````,````#``(``@`"``(``P``````!``"``(`
M``````(``@`"``(``````````@````(````"``````````(```````,``@`"
M``(``P```````@````,``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0"(`P``$```
M`"````"7D98&```$``H%`````````0`!`.`!```0````(````)>1E@8```,`
M"@4````````!``$`+P(``!``````````EY&6!@```@`*!0````````";`0``
M`````P0````````@)`````````B;`0```````P0```````#8(P```````("?
M`0```````P0```````"`4P```````-"?`0```````P0`````````4P``````
M`."?`0```````P0```````#0(`````````B@`0```````P0````````(H`$`
M`````!B@`0```````P0```````"H5P```````""@`0```````P0```````#8
M4P```````#"@`0```````P0````````X50```````#B@`0```````P0`````
M``"(5P```````$"@`0```````P0```````"05P```````$B@`0```````P0`
M``````"85P```````%"@`0```````P0```````"@5P```````&"@`0``````
M`P0```````!P5P```````&B@`0```````P0```````!X5P```````'B@`0``
M`````P0```````"P5P```````(B?`0```````00```D``````````````)"?
M`0```````00```P``````````````)B?`0```````00``!``````````````
M`*"?`0```````00``!$``````````````*B?`0```````00``!@`````````
M`````+"?`0```````00``!L``````````````+B?`0```````00``"L`````
M`````````,"?`0```````00``"P``````````````,B?`0```````00``"\`
M`````````````-B?`0```````00``#D``````````````.B?`0```````00`
M`$(``````````````/"?`0```````00``$8``````````````/B?`0``````
M`00``$L``````````````'B=`0```````@0```,``````````````("=`0``
M`````@0```0``````````````(B=`0```````@0```4``````````````)"=
M`0```````@0```8``````````````)B=`0```````@0```<`````````````
M`*"=`0```````@0```@``````````````*B=`0```````@0```H`````````
M`````+"=`0```````@0```L``````````````+B=`0```````@0```P`````
M`````````,"=`0```````@0```T``````````````,B=`0```````@0```X`
M`````````````-"=`0```````@0```\``````````````-B=`0```````@0`
M`!(``````````````."=`0```````@0``!,``````````````.B=`0``````
M`@0``!0``````````````/"=`0```````@0``!4``````````````/B=`0``
M`````@0``!8```````````````">`0```````@0``!<```````````````B>
M`0```````@0``!D``````````````!">`0```````@0``!H`````````````
M`!B>`0```````@0``!P``````````````"">`0```````@0``!T`````````
M`````"B>`0```````@0``!X``````````````#">`0```````@0``!\`````
M`````````#B>`0```````@0``"```````````````$">`0```````@0``"$`
M`````````````$B>`0```````@0``"(``````````````%">`0```````@0`
M`",``````````````%B>`0```````@0``"0``````````````&">`0``````
M`@0``"4``````````````&B>`0```````@0``"8``````````````'">`0``
M`````@0``"<``````````````'B>`0```````@0``"@``````````````(">
M`0```````@0``"D``````````````(B>`0```````@0``"H`````````````
M`)">`0```````@0``"L``````````````)B>`0```````@0``"T`````````
M`````*">`0```````@0``"X``````````````*B>`0```````@0``#``````
M`````````+">`0```````@0``#$``````````````+B>`0```````@0``#(`
M`````````````,">`0```````@0``#,``````````````,B>`0```````@0`
M`#0``````````````-">`0```````@0``#4``````````````-B>`0``````
M`@0``#8``````````````.">`0```````@0``#<``````````````.B>`0``
M`````@0``#@``````````````/">`0```````@0``#H``````````````/B>
M`0```````@0``#L```````````````"?`0```````@0``#P`````````````
M``B?`0```````@0``#T``````````````!"?`0```````@0``#X`````````
M`````!B?`0```````@0``#\``````````````""?`0```````@0``$``````
M`````````"B?`0```````@0``$$``````````````#"?`0```````@0``$,`
M`````````````#B?`0```````@0``$0``````````````$"?`0```````@0`
M`$<``````````````$B?`0```````@0``$@``````````````%"?`0``````
M`@0``$D``````````````%B?`0```````@0``$H``````````````&"?`0``
M`````@0``$P``````````````&B?`0```````@0``$T``````````````'"?
M`0```````@0``$X``````````````/U[OZG]`P"1K@$`E/U[P:C``U_6````
M````````````\'N_J=```)`1ND;Y$,(UD2`"']8?(`/5'R`#U1\@`]70``"0
M$;Y&^1#B-9$@`A_6T```D!'"1OD0`C:1(`(?UM```)`1QD;Y$"(VD2`"'];0
M``"0$<I&^1!"-I$@`A_6T```D!'.1OD08C:1(`(?UM```)`1TD;Y$((VD2`"
M'];0``"0$=9&^1"B-I$@`A_6T```D!':1OD0PC:1(`(?UM```)`1WD;Y$.(V
MD2`"'];0``"0$>)&^1`"-Y$@`A_6T```D!'F1OD0(C>1(`(?UM```)`1ZD;Y
M$$(WD2`"'];0``"0$>Y&^1!B-Y$@`A_6T```D!'R1OD0@C>1(`(?UM```)`1
M]D;Y$*(WD2`"'];0``"0$?I&^1#"-Y$@`A_6T```D!'^1OD0XC>1(`(?UM``
M`)`1`D?Y$`(XD2`"'];0``"0$09'^1`B.)$@`A_6T```D!$*1_D00CB1(`(?
MUM```)`1#D?Y$&(XD2`"'];0``"0$1)'^1"".)$@`A_6T```D!$61_D0HCB1
M(`(?UM```)`1&D?Y$,(XD2`"'];0``"0$1Y'^1#B.)$@`A_6T```D!$B1_D0
M`CF1(`(?UM```)`1)D?Y$"(YD2`"'];0``"0$2I'^1!".9$@`A_6T```D!$N
M1_D08CF1(`(?UM```)`1,D?Y$((YD2`"'];0``"0$39'^1"B.9$@`A_6T```
MD!$Z1_D0PCF1(`(?UM```)`1/D?Y$.(YD2`"'];0``"0$4)'^1`".I$@`A_6
MT```D!%&1_D0(CJ1(`(?UM```)`12D?Y$$(ZD2`"'];0``"0$4Y'^1!B.I$@
M`A_6T```D!%21_D0@CJ1(`(?UM```)`15D?Y$*(ZD2`"'];0``"0$5I'^1#"
M.I$@`A_6T```D!%>1_D0XCJ1(`(?UM```)`18D?Y$`([D2`"'];0``"0$69'
M^1`B.Y$@`A_6T```D!%J1_D00CN1(`(?UM```)`1;D?Y$&([D2`"'];0``"0
M$7)'^1"".Y$@`A_6T```D!%V1_D0HCN1(`(?UM```)`1>D?Y$,([D2`"'];0
M``"0$7Y'^1#B.Y$@`A_6T```D!&"1_D0`CR1(`(?UM```)`1AD?Y$"(\D2`"
M']:P``#P$8I'^1!"/)$@`A_6L```\!&.1_D08CR1(`(?UK```/`1DD?Y$((\
MD2`"']:P``#P$99'^1"B/)$@`A_6L```\!&:1_D0PCR1(`(?UK```/`1GD?Y
M$.(\D2`"']:P``#P$:)'^1`"/9$@`A_6L```\!&F1_D0(CV1(`(?UK```/`1
MJD?Y$$(]D2`"']:P``#P$:Y'^1!B/9$@`A_6L```\!&R1_D0@CV1(`(?UK``
M`/`1MD?Y$*(]D2`"']:P``#P$;I'^1#"/9$@`A_6_7NYJ?T#`)'S4P&ILP``
M\+0``/!CXD?YHH<$J:(C`9%D`$#YI#<`^00`@-*@7P"YH4,!D:!S`9&*__^7
MH```\*(``/``]$?Y0NQ'^>$#`JIT#`"4H```\`#81_D``$`Y8`$`-4O__Y?"
M``"00%``^4`.`+2T``#P%O__EX#61_D``$"Y3___EQ^$)#F4UD?Y@`)`N4O_
M_Y<!Z%,Y(0`?,@'H$SF``D"Y1O__EP+H4SFA7T"Y`P#\DD(``#("Z!,Y(10`
M$;5;`JFW&P#Y(7Q`DS\``^MH"@!4(/!]TS7__Y>E*T#YP@``D-0``)"$(@*1
M1SQ`^0,``/`!``#P8X`=D:@`0/DAH!V1A@"`4J)?0+D(#`"I!P0!J5\$`'&&
M!`"Y@`0`^4T!`%0A`(#2Y@"`DB00`!&C>&'XQ,PDBR$$`)%?``%K`V@D^$S_
M_U26(@*111``$07,)8OC`P"J`0``L`0`@-+`#D#Y0@P`$;^`'_@A`#*1;___
ME_4#`"J@`P`TEB("D;>3`9'`#D#YZ?[_EP```/#A`Q>J`"`3D:<$`)0``@"T
ME"("D8`.0/G-_O^75/__EW/B1_G@`Q4JHC=`^6$"0/E!``'*80,`M;5;0JGS
M4T&IMQM`^?U[QZC``U_6P`I`^>```+3N"P"4[O__%\`.0/EO__^7]0,`*N'_
M_Q<```#PX0,7J@!`$9&+!`"4P`H`^8#\_[3B"P"4XO__%Z$``/````#P`&`=
MD2'D1_DD__^7\_[_E[5;`JD@`(!2MQL`^8/^_Y<=`(#2'@"`TN4#`*KA`T#Y
MXB,`D>8#`)&@``#P`/!'^:,``/!CZ$?YI```\(3`1_FZ_O^7\?[_EZ```/``
MW$?Y0```M.G^_Q?``U_6`````,```)````*1P0``D"$``I$_``#KH```5*$`
M`/`AQ$?Y00``M"``'];``U_6'R`#U<```)````*1P0``D"$``I$A``#+(?Q#
MDR'\08LA_$&3P0``M*(``/!"_$?Y8@``M$``']8?(`/5P`-?UA\@`]7]>[ZI
M_0,`D?,+`/G3``"08`)".4`!`#6@``#P`,A'^8```+3```"0``1`^5/^_Y?8
M__^7(`"`4F`"`CGS"T#Y_7O"J,`#7];>__\7`````/^#"M&H``#P!.``D0G@
M`9']>P"I_0,`D:)C`)$!X4?Y1R``D2,`0/FC3P'Y`P"`TH$`0+F#A$#X(0C`
M6N&`'_B?``GK8?Q@TV7\:-,FW'C3I1QXDB$<"%/&''"2(0`&JJ/@0ZHA``.J
MX00!^"'^_U1&``B11`!`^4(@`)%#!$#Y11Q`^4$P0/EC``3*7P`&ZR$`!<HA
M``/*(_Q?TV$$`:HA?$"203P`^6'^_U0%$$"I@`!GG@8<0:GA`&>>P@!GGH'\
M0M,A>`2JH_Q;TT`<82XL?$"2@0%GGF,4!:JKOT&I*C./TDI0J_()$$#Y#0!F
MGJ``9YYK`0J+HOQ"TR`<8BY">`6J[P$*BR$``LJC02.+L!=`^6,`"XM-?$"2
M8P`)"Q`""HL.`&:>:_Q;TVL5`ZHA``.*(0`,RK%C0/DA``:+S@$'BR$`$(O.
M`0^+;_Q"TVL!#@OC>0.J;OU;TT(``\I"``N*SA4+JLX!`0M!``W*KPM#J7#]
M0M,0>@NJ(0`,B^\!"HML`!#*(0`/BV-\0)++_5O3C`$.BL_]0M-K%0ZJ[WD.
MJHP!`\IK`0$+3@`*BXP!#8L-`@_*`7Y`DHP!#HMB_5O3K0$+BF[]0M-"%`NJ
MK0$!RLMY"ZI"``P+K0$#B^P!"\KC?4"2L#]$J4[\6]/.%0*JC`$"BA`""HN,
M`0/*K0$0B^\!"HO.`0T+@0$!BU#\0M/-_5O3`GH"JB$`#XNM%0ZJS_U"TZT!
M`0ML`0+*X7D.JFM]0)*P/T6IC`$.BHP!"\JN_5O3$`(*BX,!`XM,``'*8P`0
MBT)\0)+.%0VJC`$-BLX!`PN,`0+*L/U"TP-Z#:KO`0J+BP$+B\W]6]-K`0^+
MK14.JL_]0M.M`0L++``#RNMY#JJP/T:I(7Q`DHP!#HJN_5O3C`$!RA`""HN"
M`0*+;``+RD(`$(MC?$"2SA4-JHP!#8K.`0(+C`$#RK#]0M/O`0J+@0$!B\S]
M6],">@VJ(0`/BXP5#JK/_4+3C`$!"VT!`LKA>0ZJ:WU`DK`_1ZFM`0Z*K0$+
MRH[]6],0`@J+HP$#BTT``<IC`!"+0GQ`DLX5#*JM`0R*D/U"T\X!`PL,>@RJ
MK0$"RN\!"HLC``S*JP$+B\W]6],A?$"2:P$/B[!#0/FM%0ZJ8P`.BL_]0M.M
M`0L+[WD.JF,``<H.`@J+BP$/RF,``HNB_5O3C'U`DF,`#HNP1T#Y0A0-JFL!
M#8JN_4+30@`#"\YY#:IK`0S*#0(*B^,!#LIK`0&+0?Q;T^]]0))K`0V+L$M`
M^2$4`JIC``**3?Q"TR$`"PNM>0*J8P`/RLL!#<IC``R+(OQ;TPP""HO.?4"2
M8P`,BT(4`:IK`0&*L$]`^4(``PMK`0[*+/Q"TXQY`:H0`@J+:P$/BT'\6]-K
M`1"+(10"JE#\0M,A``L+HP$,R@MZ`JIC``**@@$+RJ]30/FM?4"2C'U`DD(`
M`8IC``W*0@`,RF,`#HM"``V+[@$*BR_\6].PMTJI8P`.B^\5`:HN_$+3[P$#
M"\YY`:KC_5O3`0(*BV,4#ZI"``&+80$.RD)`(XMK?4"2(0`/BD-\0)(A``O*
MJ@$*BR$`#(OM_4+3;/Q;TR$`"HN,%0.JJGD/JBQ`+(NM7T#YP0$*RI!]0)(A
M``)*(G2=TBL`"XLBVZWR;_Q"TZ$!`HL-_EO3XWD#JF$!`8NM%1"J2P$#RBU`
M+8MK`0Q*KWU`DFM!+HOL_5O3+@("BP'^0M-K`0Z+(7@0JHP5#ZIL02R+L&=`
M^6L``<J.?4"2;0$-2A`"`HNJ02J+Z_U"T\W]6]-K>0^J2@$0BZT5#JI-02V+
ML&M`^2H`"\JO?4"22@$,2A`"`HM*02.+[/U;T\/]0M-*`1"+8W@.JHP5#ZI,
M02R+L&]`^6H!`\J.?4"22@$-2A`"`HM!02&+S?U;T^K]0M,A`!"+2GD/JJT5
M#JHM0"V+L'-`^6$`"LJO?4"2+``,2A`"`HN+02N+P?U"T^S]6],A>`ZJ:P$0
MBXP5#ZIL02R+L'=`^4L!`<J.?4"2;0$-2A`"`HNC02.+Z_U"T\W]6]-K>0^J
M8P`0BZT5#JJP>T#Y;4`MBR,`"\JO?4"2;``,2A`"`HN*02J+P_U"T^S]6]-C
M>`ZJ2@$0BXP5#ZI,02R+L']`^6H!`\J.?4"230$-2A`"`HNA02&+ZOU"T\W]
M6]-*>0^J(0`0BZT5#JHM0"V+L(-`^6$`"LJO?4"2+``,2A`"`HN+02N+P?U"
MT^S]6],A>`ZJ:P$0BXP5#ZIL02R+L(=`^4L!`<J.?4"2;0$-2A`"`HNC02.+
MZ_U"T\W]6]-K>0^J8P`0BZT5#JIM0"V+L(M`^2,`"\JO?4"2;``,2A`"`HN*
M02J+P_U"T^S]6]-C>`ZJ2@$0BXP5#ZI,02R+L(]`^6H!`\J.?4"230$-2A`"
M`HNA02&+ZOU"T\W]6]-*>0^J(0`0BZT5#JHM0"V+80`*RBP`#$K!_4+3(7@.
MJJ]]0)*P.U*IBT$KB^S]6],0`@*+C!4/JFL!$(MK02R+3`$!RG!]0)*-`0U*
MHT$CB^S]0M/-`0*+#OY;TXQY#ZIC``V+SA40JFY`+HLC``S*:P`+2@/^0M-C
M>!"JSWU`DJU#4ZEJ02J+JP$"B^W]6]-*`0N+K14/JDU!+8N*`0/*3@$.2NK]
M0M-*>0^J$`("B\%!(8NK?4"2(0`0BW``"LH-`@U*;OU;TW#]0M/.%0NJ"WH+
MJBY`+HNO0U2IP7U`DJQ!+(LM_%O3[P$"BZT5`:J,`0^+3P$+RHQ!+8ON`0Y*
MC7U`DA`"`HO#02.+KOU;T\X5#:JQ_4+3+_Q"TV,`$(O#`0,+X7D!JBYZ#:IP
M`0'*KT=5J1`"#$K-?4"2+'Q`D@I"*HLA``ZJX@$"BV_\6],A``.*</Q"TT(!
M`HOJ%0.JCP$-BD(!`@L#>@.J(0`/JHJ;E])O?$"2:N.Q\BM`*XLQ`@J+P0$#
MJFL!$8LA``**L0$/BE#\6],A`!&J$!8"JJY'5JE2_$+3"P(+"T)Z`JI0?$"2
MS@$*BR$`#(MC``*J;/U;TW+]0M,A``Z+C!4+JNX!$(IC``N*C`$!"V,`#JI!
M>@NJ8P`-BRY\0)(M`@J+B_U;TT(``:IC``V+DOU"TPT"#HJQNT#Y:Q4,JD(`
M#(IK`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JG+]0M-"``^+L;]`
M^<\!#8J,%0NJ(0`+BHP!`@LA``^J0GH+JB$`$(M/?$"2,`(*BXO]6]-C``*J
MDOU"TR$`$(NQPT#YL`$/BFL5#*IC``R*:P$!"V,`$*I!>@RJ8P`.BS!\0)(N
M`@J+;/U;TT(``:IR_4+38P`.B[''0/GN`1"*C!4+JD(`"XJ,`0,+0@`.JD-Z
M"ZI"``V+;GQ`DBT""HN+_5O3(0`#JI+]0M-"``V+L<M`^0T"#HIK%0RJ(0`,
MBFL!`@LA``VJ0GH,JB$`#XM-?$"2+P(*BVS]6]-C``*J<OU"TR$`#XNQST#Y
MSP$-BHP5"ZIC``N*C`$!"V,`#ZI!>@NJ8P`0BR]\0)(P`@J+B_U;TT(``:J2
M_4+38P`0B['30/FP`0^*:Q4,JD(`#(IK`0,+0@`0JD-Z#*I"``Z+<'Q`DBX"
M"HML_5O3(0`#JG+]0M-"``Z+L==`^>X!$(J,%0NJ(0`+BHP!`@LA``ZJ0GH+
MJB$`#8M.?$"2+0(*BXO]6]-C``*JDOU"TR$`#8NQVT#Y#0(.BFL5#*IC``R*
M:P$!"V,`#:I!>@RJ8P`/BRU\0)(O`@J+;/U;TT(``:IR_4+38P`/B['?0/G/
M`0V*C!4+JD(`"XJ,`0,+0@`/JD-Z"ZI"`!"+;WQ`DC`""HN+_5O3(0`#JI+]
M0M-"`!"+L>-`^;`!#XIK%0RJ(0`,BFL!`@LA`!"J0GH,JB$`#HM0?$"2+@(*
MBVS]6]-C``*J<OU"TR$`#HNQYT#Y[@$0BHP5"ZIC``N*C`$!"V,`#JI!>@NJ
M8P`-BRY\0)(M`@J+B_U;TT(``:J2_4+38P`-B['K0/D-`@Z*:Q4,JD(`#(IK
M`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JD(`#XNQ[T#YSP$-BHP5
M"ZHA``N*C`$""W+]0M,A``^J0GH+JB$`$(N+_5O3,`(*BR$`$(MK%0RJ:P$!
M"T]\0)*Q!UZI8P`"JK`!#XIC``R*DOU"TV,`$*I,>@RJ,0(*BY!]0))"``RJ
M8P`.BV[]6]/.%0NJ0@`+BF,`$8OQ`1"*PP$#"T(`$:IN_4+3(0`*B\MY"ZI"
M``V+;?Q;TVY]0))"``&+K14#JH$!"ZI20"V+K/M`^0("#HHA``.*37Y`DB$`
M`JIB_$+30W@#JHH!"HLA``^+K/U;TV(!`\HA``J+C!4-JJ_]0M,L0"R+00`2
M2B$`$(N1?4"2JL-?J<(ZF-)"3+GR*_Y;TTH!`HMK%1&J(0`*B^IY#:HK0"N+
M80`*RF]]0)(A``Q*[?U;TPP"`HLA``Z++OY"T\YY$:HA``R+K14/JDP!#LHM
M0"V+H0=!^;!]0)*+`0M*(0`"BPS^6]-K02.+X_U"TVL!`8N,%1"J87@/JFQ!
M+(NC"T'YRP$!RH]]0))K`0U*8P`"B^W]6]-J02J+"_Y"TVMY$*I*`0.+K14/
MJB,`"\I-02V+J@]!^;!]0))C``Q*2@$"BPS^6]-C0"Z+[OU"TV,`"HN,%1"J
MRGD/JFQ`+(MN`0K*HQ-!^8]]0)+.`0U*8P`"B^W]6]/!02&+#OY"TR$``XNM
M%0^JPWD0JBU`+8M0`0/*H1=!^:Y]0)(0`@Q*(0`"B\S]6],+0BN+\/U"TVL!
M`8N,%0ZJ`7H/JFQ!+(MP``'*JQM!^8]]0)(0`@U*:P$"B^W]6],*0BJ+T/U"
MTTH!"XNM%0^J"WH.JDU!+8LP``O*JA]!^:Y]0)(0`@Q*2@$"B\S]6],#0B.+
M\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HR-!^8]]0)(0`@U*8P`"B^W]6],!
M0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H2=!^:Y]0)(0`@Q*(0`"B\S]
M6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JRM!^8]]0)(0`@U*:P$"
MB^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*JB]!^:Y]0)(0`@Q*
M2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HS-!^8]]0)(0
M`@U*8P`"B^W]6],!0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H3=!^:Y]
M0)(0`@Q*(0`"B\S]6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JSM!
M^8]]0)(0`@U*:P$"B^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*
MJC]!^:Y]0)(0`@Q*2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(NO
M0T'Y8P$*RI!]0))M``U*H4$ABP/^6]/M`0*+S_U"TV,4$*HA``V+[7D.JB%`
M(XNO1T'Y0P$-RBY\0))C``Q*#/Y"T^\!`HN,>1"J:T`KB\/]6]-K`0^+8Q0.
MJK`!#,JO2T'Y8P`+"P$"`4K+_4+3*D`JB^$!`HMB_%O32@$!BT(4`ZIA>0ZJ
M0@`*"R8`!@L(X4?YAP$'"ZD!"0M%``4+@P`#"P8<`:D%#`"I"1``^:%/0?D`
M`4#Y(```RH```+7]>T"I_X,*D<`#7]9T^O^7'R`#U?U[O*G]`P"1\PL`^8`'
M`+2B``#0N!\`^4+X1_E8`$#Y.`<`M+43`/D5`(!2`@!`.5_T`'%$&$!Z00,`
M5!,#0/F3!0"TMM\"J;5^0).T#P#Y]P,!JO8#`*KT`QBJX`,3JN(#%:KA`Q:J
M+/K_EX```#5@:G4X'_0`<4`"`%23CD#X\_[_M;370:FVWT*IN!]`^>`#$ZKS
M"T#Y_7O$J,`#7];U`P"JHAY`.%_T`'%$&$!ZH?__5+4"`$OA__\7'R`#U90"
M&,NU!@"1E/Y#D_0"`+ES`A6+X`,3JK@?0/FTUT&IMM]"J?,+0/G]>\2HP`-?
MUK430/FX'T#YYO__%Q,`@-+D__\7$P"`TK@?0/GA__\7_7N\J?T#`)'U6P*I
MM@``T/-3`:FS``#0]0,`JL#B1_ES^D?YM-,`D0$`0/FA'P#Y`0"`TN$#%*K@
M`Q6JK?__E^`!`+2C-X"Y8@)`^4`,`XL!!$#Y07@C^.'^_[0`(`"1`01`^0$`
M`/FA__^UX0,4JN`#%:J?__^78/[_M=;B1_FA'T#YP`)`^2```,J@``"U\U-!
MJ?5;0JG]>\2HP`-?U@;Z_Y<?(`/5_7NYJ?T#`)'S4P&I\P,!JO5;`JFU``#0
M]V,#J?0#`*JAXD?Y8`)`.2(`0/FB-P#Y`@"`TA_T`'%S%I.:X`,3JH#Y_Y?V
M`P"JH9,!D>`#%*I^__^7X`<`M/<#`*IY^?^7'P`6ZZ(&`%2X9X"YMP``T!CS
M?=.``D`Y'_0`<0080'J`#`!4X0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+(7Q`
MD_?Z1_G`"@"1```!B_8"0/F<^?^7P&HX^*`+`+2C9X"Y@`8`D>("0/F!`D`Y
M/_0`<4)X8_@D&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5$$$`)&@
M!X!20```.6`60#@@%``XP/__-0``@%*UXD?YHC=`^:$"0/E!``'*H0@`M?-3
M0:GU6T*I]V-#J?U[QZC``U_6``"`TF%J8#CA:B`X``0`D:'__S7P__\7MP``
MT+EK!*F[*P#YX/I'^1@`0/D``T#Y@`4`M.$#&*H``(!2`@``%.`#&2HBC$#X
M&00`$:+__[4`#``1`'Q]DZ$``/`BB$"Y@@(`-2(`@%(BB`"Y7_G_E_L#`*K`
M`P"T.G]`D^$#&*I8\WW3X@,8JACY_Y?@^D?Y&P``^5H'`)%_>SKXN6<`N;LK
M0/FY:T2II?__%Q\@`]7A`P"JX`,8JGSY_Y?[`P"JX/I'^1L``/D[`0"T.G]`
MDUCS?=/P__\7`0"`TJ/__Q<``H#2&0"`4MS__Q>Y:T2INRM`^0``@!*X__\7
MN6L$J;LK`/EU^?^7_7NRJ?T#`)'S"P#YLP``T&'B1_DB`$#YHF\`^0(`@-+`
M``"TM`\`^?0#`*H!`$`Y00$`-;0/0/ESXD?YH6]`^6`"0/D@``#*P`D`M?,+
M0/G]>\ZHP`-?UK87`/D%^?^7]@,`JN`&`+2W8P.I%P``T!@``-"Z)P#Y]V(/
MD1B##Y&Z8P&1M1,`^>`#%JJ5^?^7``8`M!5,`)'A`Q>JX`,5JFSY_Y<@__\T
MX0,8JN`#%:IH^?^7H/[_-+DC`/G@`Q2JT/C_E_D#`*K@`Q6JS?C_EP``&0L`
M"``1`'Q`DP'Y_Y?E`Q6JY`,4J@,``-!CH`^1^0,`J@(`@)(A`(!2Q?C_E^(#
M&JKA`QFJ``"`4LGX_Y<?!``QH```5*!K0+D`#!02'Q!`<8`"`%3@`QFJH?G_
ME^`#&:IC^?^7N2-`^=/__Q>T#T#YMA=`^;S__Q<?(`/5X`,6JAOY_Y?@`Q2J
M1?G_E[370:FVWT*IN!]`^;HG0/FR__\7X`,9JJ+__Y?M__\7M-<!J;;?`JFX
MYP.INB<`^1#Y_Y<?(`/5_7NUJ>$#`*K]`P"1\U,!J;,``-#T`P"JHJ,`D6/B
M1_D``(!29`!`^:17`/D$`(#2.OG_E^`!`#6A.T"Y`@"44B$,%!(_$$!Q)!!"
M>F`!`%1SXD?YHE=`^6$"0/E!``'*@0$`M?-30:G]>\NHP`-?U@``@%+W__\7
M00"`4N`#%*H"^?^7'P``<>`7GQKQ__\7ZOC_EQ\@`]40"H+2_V,PR^+_@=+]
M>P"I_0,`D?,+`/FS``#0]5L"J;4C`9'W8P.I]@,`JF/B1_GW`P&J````T.$#
M%:ID`$#YI"<(^00`@-(`P`^1<?C_EQ\``'%M!0!4`@0`4;0/`/FA``#0H\IB
M."'41_DX`$"Y@P,`-.(#`"I4?$"3X06`4N(#%*K@`Q6J)OG_E\`"`+3@`Q@J
ML_C_E^,#%*KB`Q6JX0,6JB?Y_Y>T#T#Y<^)'^:$G2/E@`D#Y(```RJ`"`+7U
M6T*I$`J"TO=C0ZG]>T"I\PM`^?]C,(O``U_6'R`#U<+\_S6T#T#YX`,8*IWX
M_Y?B`Q>JX0,6JGKX_Y?L__\7H```T`#41_D8`$"Y]___%[0/`/FC^/^7_7N_
MJ:```-#]`P"1`-1'^0``0+F-^/^7H@``T`,``-#]>\&H`0``T$+01_EC@`Z1
M(0`0D<GX_Q?]>[ZI_0,`D?,+`/FS``#0<]9'^6`"0+E^^/^7Z___EV`"0+E[
M^/^7\PM`^?U[PJ@$``#0A$`=D0(``+`!``#0!0"`4N,#!*I"P#B1(8`0D=#X
M_Q<?(`/5$`J$TO]C,,L`"(+2_7L`J?T#`)'S4P&IM```T/5;`JFV`P"+@.)'
M^;/C`)$!`$#YH2<0^0$`@-(P^/^7Y`,`*@4``-`#``#0I>`0D6,`$9$B`(+2
M(0"`4N`#$ZKW]_^7`@""TN$#%JK@`Q.J__?_EP`#^#?S`P"J``0`$0!\0),B
M^/^7]0,`JL```+1S?D"3X0,6JN(#$ZK8]_^7OVHS.)3B1_G@`Q6JHB=0^8$"
M0/E!``'*(0$`M?-30:D0"H32]5M"J?U[0*G_8S"+P`-?UA4`@-+S__\72/C_
MEQ\@`]7(__\7'R`#U1`>@M+_8S#+_7L`J?T#`)'U6P*IM@``T/-3`:GU`P&J
MPN)'^?,#`*JADP&1````T$,`0/FC=PCY`P"`T@!`$9'"_?^7]`,`JN$%@%+@
M`Q.JA/C_ER`"`+0```#0X0,3J@"`$9$G_O^7X`,3JM;B1_FB=TCYP0)`^4$`
M`<KA#`"U\U-!J1`>@M+U6T*I_7M`J?]C,(O``U_6MQL`^>`#$ZJY(P#Y%P``
MT+LK`/FE]_^7X<(1D?D#`"K@`Q6JG??_E_L#`*H@"@"TN!\`^;6C`Y&Z)P#Y
M&```T!H``-`8XQ&16F,/D6`#0#E`!@`TM```M.$#&ZK@`Q2J)OC_EV`$`#3@
M`QNJC_?_EV'#((LA\%\X/[P`<>$``%0`!`!18<,@BW_+(#@A\%\X/[P`<6#_
M_U0A!P`1(```"Q_\/W$,`P!4`P``T.8#$ZKE`QBJY`,;JF,`$I$"`(+2(0"`
M4N`#%:I\]_^7HJ,!D>$#%:H``(!2@/?_EZ```#6@>T"Y``P4$A\@0'%@`@!4
MX<(1D0``@-)H]_^7^P,`JF#Z_[6W8T.IN6M$J;LK0/FL__\7'R`#U;0``+3A
M`QJJX`,4JO7W_Y=`_O\T^P,:JB``@%+9__\7(0"`4N`#%:KB]_^78/W_->$#
M%:H```#0`(`1D<7]_Y?@`Q6JO_?_E[LK0/FW8T.IN6M$J9K__Q>W&T#YN2-`
M^;LK0/F1__\7MV,#J;EK!*F[*P#YN_?_EP$`0#GB`P"JP0``-``$`)$_O`!Q
M0A"`F@$`0#F!__\UX`,"JL`#7]:`"`"T_7N^J?T#`)'S4P&I\P,`JA0`0#D4
M`P`T-??_EP`$`-%B`@"+?P("Z^(#`%1@:F`X'[P`<:```%08```40`!`.1^\
M`'&A`@!40@0`T7\"`NMA__]4G[X`<>```%3S4T&I````L/U[PJ@`X!&1C/?_
M%Q\@`]7S4T&I````L/U[PJ@`8`^1AO?_%Q\@`]5``$`Y'[P`<8`!`%1"!`#1
M?P("ZV/__U1_`@+K8/W_5$($`-%_`@+KX@``5$``0#D?O`!Q@0``5$($`-%_
M`@+K8___5$(`$\M`"`"1'P1`\0@"`%2D``#0A*`"D0,`@M)"!`"1X0,3JN`#
M!*HY]_^7\U-!J?U[PJC``U_6'R`#U0```+``8`^18O?_%Q\@`]4``(#2]___
M%_U[N*D!``"P(8`.D0```+#]`P"1\U,!J;,``+#U6P*I`"`2D6/B1_D6``"P
M]V,#J1<``+`F'$&I8@!`^:(_`/D"`(#2)!1"J:8?!:DA8$!Y&```L*'C`'D4
M``"PI!<&J92B$Y&U,P&1'OW_EP```+``8!*1&_W_EP```+``@!*1&/W_EP``
M`+``P!*1%?W_E\#B$I$3_?^7````L``@$Y$0_?^7X$(1D0[]_Y<`8Q.1#/W_
ME^`#%*H*_?^7````L`#@$Y$'_?^7````L`"`$9$$_?^7````L.$#%:H`(!21
MO/S_EX```+3A`P"JX`,4JB;]_Y<```"PX0,5J@"`%)&T_/^7H```M`(``+#A
M`P"J0.`4D1W]_Y<```"PX0,5J@`@%9&K_/^70`(`M.$#`*K@0A&1%?W_EP$`
M`+#`XA*1(0`6D1']_Y=SXD?YH3]`^6`"0/D@``#*0`,`M?-30:GU6T*I]V-#
MJ?U[R*C``U_6````L.$#%:H`8!61E?S_EX`!`+4!``"PM$,!D4(!@-(AP!61
MH(<!D=3V_Y?@_/\U@6X`D0!C$Y'X_/^7X___%^$#`*H`8Q.1]/S_E]___Q?V
M]O^7'R`#U?U[O:G]`P"1\U,!J;,``+"T``#08>)'^8`20+DB`$#YHA<`^0(`
M@-(?!``Q(`$`5'/B1_FB%T#Y80)`^4$``<HA`@"U\U-!J?U[PZC``U_6H9,`
MD0```+``8!.1:_S_E^$#`*H``(!2H0``M"``0#D?P`!Q!!A`>N`'GQJ`$@"Y
M[/__%]/V_Y?]>[^I_0,`D73V_Y?S]O^7@```M```0/G]>\&HP`-?U@``@-+]
M__\7_7N[J?T#`)'S"P#YLP``L/5;`JD5``"P]QL`^;<B%I%BXD?Y]@,`JJ$3
M`9'@`Q>J0P!`^:,G`/D#`(#21_S_EV`!`+2T#P#Y]`,`J@$`0#G!```TX0,6
MJB+W_Y<@`@"TM`]`^04``!2T#T#YX0,6JJ`B%I&G_/^7<^)'^:$G0/E@`D#Y
M(```RJ`#`+7U6T*I\PM`^?<;0/G]>\6HP`-?UN`#%JHK]O^7]0,`JN`#%*HH
M]O^7H`(`BP`(`)%=]O^7Y@,4JN0#%JH%``"P`P``L*7`$9%C`!*1`@"`DO4#
M`*HA`(!2'_;_E^$#%:K@`Q>JB/S_E[0/0/G@__\7M`\`^8CV_Y<?(`/5$#J0
MTO]C,,NJ``#02D$`D0L$D-+]>P&I_4,`D:T#"XM$E4"I]5L#J;8``+#X)P#Y
M^B\`^?@#`*KS$P#YM3,"D<SB1_D:``"P0`5#J8X!0/FNS0#Y#@"`TD(-0JF@
M!PVI1AU$J:07":E()46IH@\,J4L-0/GA`Q6J2C%`^4!#$9&F'PZIJ*<*J:M3
M`/FJ7P#Y\/O_EX```+0!`$`Y\P,`JH$1`#6T#P#YMQL`^;DC`/F[*P#YA___
ME_0#`*I@$0"TX`,4JN'U_Y<`^'_3``0`D1;V_Y>$`D`Y]P,`JH0!`#0```"P
M\P,7JAF`%I'@`Q.JXP,9J@(`@)(A`(!2U_7_EW,*`)&$'D`X)/__-:!C0/G`
M"P"TN0,#D3,`@-(%```4<P8`D2`/$XL`@%_XX`H`M.$#%:K'^_^7]`,`JB#_
M_[0!`$`YX?[_-";]_Y>@_O\TX`,4JBGV_Y?[`P"J8`D`M.`#&ZJY]?^7\P,`
MJN`#%ZJV]?^7$P`3"W,2$!$9``"P<WY`D^`#$ZKH]?^7YP,7JB7C$9'D`QNJ
M!@``L`,``+#&H!:18\`6D0(`@)+T`P"J(0"`4JGU_Y<!.(!2X`,4JI+V_Y<?
M!``QH0``5(?V_Y<%`$"YOT0`<6$8`%2WPP.1O"\`^>$#%*KB`Q>J``"`4D+V
M_Y?\`P`JH```-:`#0;D`#!02'Q!`<<`)`%2@``"P`P-`^>0#%*H"``"P`,Q'
M^4(`&)$A`(!2$P"`T@``0/D6]O^7M`]`^;MS1:FW&T#YN2-`^=;B1_D!!)#2
MH0,!B^`#$ZHBS$#YP0)`^4$``<H!.`"U]5M#J1`ZD-+]>T&I\Q-`^?@G0/GZ
M+T#Y_V,PB\`#7]8?(`/5N4,"D10`@%(SVW3XLP$`M&`"0#E@`0`TX`,3JI0&
M`!'._/^7(/__-.`#$ZK1]?^7^P,`JB#U_[4SVW3XL_[_M1L`@-*E__\7"O__
ME^`#$ZK(]?^7\P,`JMG__Q<?(`/5MZ,"D1,`@%+@VG/X@`$`M.$#%:IS!@`1
M5/O_EV#__[0!`$`Y(?__-+KU_Y?T`P"J0.W_M>#:<_C`_O^UH`&`TH#U_Y<4
M``"P]P,`JF0*@%*48A:1:?__%[L+0;E9]?^7?P,`:P'V_U2@`T&Y`"``$A\`
M!W&!]?]4X`,3JG'U_Y?A`Q6J\P,`J@```+``8!F1-OO_ER`-`+05`T#YG?7_
ME^$#`*K@`Q6J7OW_E_4#`*I`#`"TX`,5JBKU_Y?[`P"J'PP`<>T!`%0`?$"3
M`0``L``0`-$A@!F1H`(`B[7U_Y<``0`U?Q,`<8`E`%1@$P!1H,(@BP#P7S@?
MO`!QX"0`5)C^_Y?````U`0"`4N`#%:KL]?^7H'<`N4`)`#4!``"P(0`6D0``
M`+``8!.1??O_ESGC$9$_]?^7%0``L+5"'9'F`P`J`P``L.<#%:KE`QFJY`,4
MJF,`&I$"`("2(0"`4N`#$ZH7``"P^`,9J@'U_Y?W0AJ1$0``%.+U_Y<``$"Y
M'T0`<4$"`%0J]?^7]0,`^9P'`!'F`P`JYP,<*N4#&*KD`Q2JXP,7J@(`@)(A
M`(!2X`,3JN_T_Y<!.(!2X`,3JMCU_Y<?!``Q@/W_5.`#%*J4]?^7X0,3JD!#
M$9%1^_^7X`,3JHO^_Y>T#T#YNW-%J;<;0/FY(T#Y6?__%Z```+`#`T#YY`,4
MJ@(``+``S$?Y0@`7D2$`@%(3`(#2``!`^6#U_Y>T#T#YMQM`^;DC0/F[*T#Y
M2O__%Q4#0/F>__\7H^,&D4(`@%+U`P.J(0*`DJ,_`/D?]?^7H'=`N<(`@-+A
M`Q6JC_7_EZ#C1CF````UH.=&.1\,`7&@'`!4H'=`N0(`@%(!`(#2O*,$D1'U
M_Y>__Q&IX.(`D21@A-(C<972PI^;TL&.BM*@-P#Y`#Z<TJ3HK/*C^;WR0A>S
M\D$&HO)`>KCRI`\/J:('$*F_:P&YH(L`^:!W0+D"`)#2H3]`^7#U_Y?C`P"J
M]0,`*A\``'&M"`!4I8M1J6%\0).@:T&YI`P!"[\`!.M"E(*:071!BZ2'$:G@
M$P`T`0B`4C4``$NA/T#Y?P`5:Z(W0/EUT)4:NWY`DZ,S`/E`P""+X@,;JGST
M_Y>@:T&YHS-`^:`"``N@:P&Y'P`!<>'[_U2@/T#Y=0`52QL`&XO@`Q>J1_;_
ME[_^`''-`@!4M0(!4:!^!E.@8P"Y&&0:4Q@#`9%X`QB+8`="J8`'`JED%T"I
MA!<`J6(/0:F"#P&I9A]#J88?`ZE[`P&1X`,7JC3V_Y<?`QOK@?[_5*!C0+FU
M&@!+H#=`^0,)@-*B?D"3X0,;JI'T_Y>U:P&YH'=`N0(`D-*A/T#Y+/7_E^,#
M`*KU`P`J'P``<:SW_U2@=T"YSO3_E[7C4:GB#X`2H2(#4R`$`!$?X`!Q@LLA
M.&P-`%3CX@"1`@>`4D(``$L!`(!20GQ`DV#`((N8]/^7`?]8TP#_4-.A@P4Y
MH?Y8TZ"'!3D`_TC3H(L%.:#^4-.@EP4YH/Y(T[B/!3F\(P:1H9,%.;C'!9&U
MGP4YFZ,`D:";!3G@`Q>J__7_E_4#'*JF%T^I````L*,+4*D7@!:1H8M`^<C\
M4-/'_$C3H/Q8TZG\4-.HQP4YI\L%.:C\2--G_%C3H-,%.6#\2-/$?!A3IL\%
M.6K\4-.IUP4Y)OQ8TZC;!3E)_%C32/Q0TZ7?!3FGXP4Y)?Q0TT?\2-.@ZP4Y
MI,,%.2#\2-.JYP4YH^\%.:GS!3FH]P4YI_L%.:+_!3FF`P8YI0<&.:`+!CFA
M#P8Y`@``%`070#C@`Q6JXP,7J@(`@)(A`(!2M0H`D0CT_Y=_`Q7K`?__5`<`
M`+#F`QRJYT`=D0,``+"_PP8Y)>,1D>0#%*ICP!F1`@"`DB$`@%+@`Q.J^O/_
MEQ#__Q>[/T#Y=___%Q@'0/DXV_^TX`,8JN_S_Y<?#`#QJ=K_5``0`-$!``"P
M``,`BR&@&9%\]/^7'P``<;42F)K-_O\7`@B`4D(``$M"?$"3`0"`4OOB`)%@
MPR"++O3_E^`#%ZJF]?^7H(,(D1_\,*G__@2I__X%J?\V`/F/__\7H.M&.1\$
M`7%!X_]4H.]&.1\,`7'AXO]4H/-&.1\@`7&!XO]4H/=&.1\4`7$AXO]4MW=`
MN4(`@%(A!X"2X`,7*B'T_Y>U/T#Y(@6`TN`#%RKA`Q6JD/3_EP<``+#F`Q6J
M`P``L.=`'9&___\7NW,%J;0/`/FW&P#YN2,`^2KT_Y<?(`/5_7NXJ:```+#]
M`P"1]QL`^;<``+#S4P&I\]9'^?5;`JFUTP&1^B<`^0#@1_FU,P#Y`0!`^:$_
M`/D!`(#28`)`N0CT_Y?T`P"J8`)`N07T_Y>!XD(Y`>0".0```+#A`Q6J`.`2
MD9WY_Y>```"T`0!`.3_$`'$@%`!4I/S_E_;61_G``D"Y]_/_EP$``+!C`8!2
M(@"`4B&@&I$*]/^7(!8`M+@?`/FA``#0-2`"D:$W`/D!"$#YV@)`N:`&0+DX
M%$#Y'P0`<>T9`%2Y(P#Y&8"`4KMS!:D4`(!2,P"`4AD$H'(+```4'R`#U6$(
M0/G@`QRJ#/3_EZ$&0+D@!``U<P8`$90&`!$_`!-KK0,`5.`#&BK4\_^7`P"`
M4H)^0)/A`QBJ./3_E_L#`*J`$P"T`P!`^:0&0/G:`D"Y8`Q`N9S8<_@``!D*
M'P`0<0#]_U3@`QHJQ//_EV$#0/E#`(!2`@"`TK#S_Y?A`P"JX`,<JNWS_Y?:
M`D"YH09`N2#\_S0@!`!1'P`4:R`,`%2XYT.INW-%J>`#&BJS\_^78P"`4@$`
M`+`B`(!2(<`:D<;S_Y?S`P"JH`$`M/361_F``D"YJ?/_EV$*0/D"``"P0N`:
MD2$`0/F$\_^78`I`^0``0/D`#$"Y0!"P-_361_F``D"YG?/_EP$``)!C`(!2
M(@"`4B$`&Y&P\_^7\P,`JJ`!`+2A,T#Y````D`"`$9$P^?^7]0,`JH`"0+GU
M#`"TCO/_EV$*0/GB`Q6J(0!`^6KS_Y?WUD?YH#=`^10@`I'@`D"YA?/_E_,#
M`*K@`D"Y@O/_ER(`@%(!``"0(2`;D;KS_Y<"``"0X0,`JD*`&Y'@`Q.J6?/_
ME^`"0+EW\_^7'^0".:$S0/D```"0`$`1D1#Y_Y>`"@#Y\P,`JF`&`+0!.(!2
MX`,3JOCS_Y<!!``1/P0`<02(47JA"@!4H```D!K@1_FA/T#Y0`-`^2```,J`
M"0"U\U-!J?5;0JGW&T#Y^B=`^?U[R*C``U_6'R`#U0`$0#D`[/\T7O__%Q\@
M`]4_!`!Q[?/_5*`W0/DS`(!2]=9'^10@`I$#```4'R`#U;H"0+G@`QHJ3//_
ME^$#&*H&\_^7@`9`N7,&`!$?`!-K#/__5.#61_FXYT.INW-%J1H`0+F-__\7
MH```L-H"0+F@-P#YB?__%X`&0/G%_/^7@`H`^?,#`*I`^?^U````D+CG`ZF[
M<P6I`*`;D7/S_Y>A-T#YX-9'^2$@`I$A!$"Y&@!`N2`$`%$?`!1KH>[_5-3_
M_Q<?(`/5*//_EZ`W0/EB"D#Y`"`"D0$$0/E``$#Y(0!`^4GZ_Y>7__\7'R`#
MU8`"0+D=\_^780I`^2$`0/ER\_^7>O__%[@?0/EC__\7N.<#J;MS!:DD\_^7
MH3=`^>,#`"J[<P6IX@,3JCP@`I&XYP.I`0``D"!`')&!!T#Y(0!`^4GS_Y?]
M>[ZI_0,`D?-3`:GT`P"J9/O_EP$`0#GS`P"JP0``-``$`)$_O`!Q<Q*`F@$`
M0#F!__\U%_S_EY\"`/$$&$!Z@0``5/-30:G]>\*HP`-?UH`"0#F`__\T`0``
MD((`@-(AH!:1X`,3JM+R_Y?`_O\UX`,4JO-30:G]>\*HA?G_%Z,``+!C!$#Y
MIO+_%P````#]>[RI_0,`D?37`:FT``"0M0``D)0B+)&U`BR1]M\"J90"%<OX
M'P#YE/Y#D_8#`"KW`P&J^`,"JE;R_Y>4`0"TLPL`^1,`@-*C>G/XX@,8JN$#
M%ZK@`Q8J<P8`D6``/]:?`A/K(?__5+,+0/GTUT&I]M]"J?@?0/G]>\2HP`-?
MUL`#7];]>[^I_0,`D?U[P:C``U_6``````$``@``````<&5R;'AS:2YC````
M`````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@```````````N
M`````````"XN````````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/
M5`````!E>&4``````"]P<F]C+R5I+R5S``````!005)?5$5-4```````````
M4$%27U!23T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU
M3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.````````
M`%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$
M14)51P``````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)
M4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````````
M``!005)?0TQ%04X]````````,0````````!,1%],24)205)97U!!5$@`4UE3
M5$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*````````4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S``````````!!
M4D=6`````!@`````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI6
M15)324].`````#$N,#0U````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"5S````
M````+64````````M+0```````%5315(`````55-%4DY!344``````````%1-
M4$1)4@``5$5-4$1)4@!414U0`````%1-4```````+W1M<`````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H
M7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O
M9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E
M="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F
M<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@
M)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE
M('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N
M<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP
M;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@
M?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T
M('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@
M7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(
M+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@
M)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U
M:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0[
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M
M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G
M/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D
M(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F
M:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]
M"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I
M;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^
M<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I
M.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE
M;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C
M86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT
M("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP
M;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L
M;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA
M;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````@)````````-@C
M`````````0`````````!``````````$`````````RP$````````!````````
M`-8!`````````0````````#@`0````````$`````````+P(````````!````
M`````(@#`````````0````````"P`P````````P`````````D!P````````-
M`````````(13````````&0``````````FP$``````!L`````````"```````
M```:``````````B;`0``````'``````````(`````````/7^_V\`````8`(`
M```````%`````````(@-````````!@````````!0`P````````H`````````
M%04````````+`````````!@`````````%0````````````````````,`````
M````8)T!```````"```````````&````````%``````````'`````````!<`
M````````D!8````````'`````````-@3````````"`````````"X`@``````
M``D`````````&``````````>``````````@`````````^___;P`````!```(
M`````/[__V\`````>!,```````#___]O``````,`````````\/__;P````">
M$@```````/G__V\`````$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+`<````````
ML!P```````"P'````````+`<````````L!P```````"P'````````+`<````
M````L!P```````"P'````````+`<````````L!P```````"P'````````+`<
M````````L!P```````"P'````````+`<````````L!P```````"P'```````
M`+`<````````L!P```````"P'````````+`<````````L!P```````"P'```
M`````+`<````````L!P```````"P'````````+`<````````L!P```````"P
M'````````+`<````````L!P```````"P'````````+`<````````L!P`````
M``"P'````````+`<````````L!P```````"P'````````+`<````````L!P`
M``````"P'````````+`<````````L!P```````"P'````````+`<````````
ML!P```````"P'````````+`<````````L!P```````"P'````````+`<````
M````L!P```````"P'````````+`<````````L!P```````"P'````````+`<
M````````L!P```````"P'````````+`<````````L!P```````"P'```````
M`+`<````````$)L!``````"`4P``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!3``````````````````#0(```````````````````````````
M````````````````````````"*`!``````#_____`````*A7````````V%,`
M`````````````````#A5````````B%<```````"05P```````)A7````````
MH%<``````````````````'!7````````>%<``````````````````+!7````
M````1T-#.B`H1&5B:6%N(#<N,RXP+3(S*2`W+C,N,`!'0T,Z("A$96)I86X@
M-RXS+C`M,3,I(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````(``````````@```````!L````````````````````!````````````
M````````$P````<````"`````````!P"````````'`(````````@````````
M````````````!````````````````````"$````'`````@`````````\`@``
M`````#P"````````)`````````````````````0````````````````````T
M````]O__;P(`````````8`(```````!@`@```````.P`````````!0``````
M```(````````````````````/@````L````"`````````%`#````````4`,`
M```````X"@````````8````#````"``````````8`````````$8````#````
M`@````````"(#0```````(@-````````%04```````````````````$`````
M``````````````!.````____;P(`````````GA(```````">$@```````-H`
M````````!0`````````"``````````(`````````6P```/[__V\"````````
M`'@3````````>!,```````!@``````````8````#````"```````````````
M`````&H````$`````@````````#8$P```````-@3````````N`(````````%
M``````````@`````````&`````````!T````!````$(`````````D!8`````
M``"0%@`````````&````````!0```!0````(`````````!@`````````?@``
M``$````&`````````)`<````````D!P````````4````````````````````
M!````````````````````'D````!````!@````````"P'````````+`<````
M````(`0``````````````````!``````````$`````````"$`````0````8`
M````````T"````````#0(````````+0R```````````````````(````````
M````````````B@````$````&`````````(13````````A%,````````0````
M````````````````!````````````````````)`````!`````@````````"8
M4P```````)A3````````4$````````````````````@`````````````````
M``"8`````0````(`````````Z),```````#HDP````````0`````````````
M```````$````````````````````H@````X````#``````````";`0``````
M`)L````````(````````````````````"``````````(`````````*X````/
M`````P`````````(FP$```````B;````````"`````````````````````@`
M````````"`````````"Z````!@````,`````````$)L!```````0FP``````
M`%`"````````!@`````````(`````````!``````````PP````$````#````
M`````&"=`0``````8)T```````"@`@``````````````````"``````````(
M`````````,@````!`````P``````````H`$```````"@````````@```````
M``````````````@```````````````````#.````"`````,`````````@*`!
M``````"`H````````"@0```````````````````(````````````````````
MTP````$````P````````````````````@*`````````Z````````````````
M`````0`````````!``````````$````#`````````````````````````+J@
F````````W`````````````````````$`````````````````````
